:tocdepth: 2

.. _authors:

Authors
=======

Aqtinstall is written and maintained by Hiroshi Miura <miurahr@linux.com>

Original qli-installer is written by Linus Jahn

Significant contributions for improvements of version 2.0 and 2.1 by David Dalcino
David also leads many developments and reviews effort after 2.0.

All contributors, listed alphabetically, are:

* Alberto Mardegan(ignore_hash option)
* Andrei Yankovich (tools ifw installation)
* Aurélien Gâteau (patching to qmake)
* Benjamin O (Github Actions and more)
* Christian Hoffmann (Update mirror list)
* David Dalcino (Many improvements on CI automations, commands, tests, documents and so on)
* Doronin Stanislav (document)
* Fabrice Le Bars (32bit binary)
* Felix Barz (Android, Explicit extra module installation)
* Gamso (improve parsing of update.xml)
* Julien Marrec (mypy, type hints)
* Kyle Altendorf (7z binary path search)
* @lebarsfa (ignore_hash/hash_algorithm options)
* @lightmare (Documents)
* Martin Delille (Documents)
* Mike Tzou (Update fallback url)
* mite-user (folder index handling of download web sites)
* Mizux Seihax (Qt versions)
* Mozi (CI/workflow improvement, log format)
* Nelson Chen (CI tests)
* @nikitalita (Binary distribution)
* @pylipp (Documents)
* @Steveice10 (MacOS binary build)
* Sztergbaum Roman (Version database)
* Thomas Grainger (CLI entry point)
* @tsteven4 (fix patching to qmake, pkgconfig and libtool)
* Vadim Peretokin (Version database)
* Vladyslav Hnatiuk (Version database)
* @ypnos (Documents)

and many other participants and contributors.
If you find a missing name to record, please feel free to tell me.